@@ -12,10 +12,10 @@ from util import anticache_headers
 from template import render_to_response
 
 
-def route(url, name=None):
+def route(url, urlname=None):
     ''' Декоратор роутинга '''
     def wrapper(func):
-        urls.add_rule(url, func, name)
+        urls.add_rule(url, func, urlname)
         return func
     return wrapper
 
@@ -52,7 +52,7 @@ def to_template(fn, **response_kwargs):
     def decorator(func):
         def wrapper(rq, *args, **kwargs):
             res = func(rq, *args, **kwargs)
-            if isinstance(res, Response):
+            if not isinstance(res, dict):
                 return res
             return render_to_response(
                 rq, fn, res, **response_kwargs)
@@ -82,3 +82,25 @@ def basic_auth(func):
         rq.basic_user
         return func(rq, *args, **kwargs)
     return wrapper
+    
+def view(url_or_list, template='text', **response_kwargs):
+    '''
+    Роутинг + шаблонизация + дефолтный урлнейм (app.func_name)
+    '''
+    def wrapper(func):
+        mod_name = func.func_globals['__name__']
+        app_name = mod_name[:-6] if mod_name.endswith('.views') else None
+        urlname = '%s.%s' % (app_name, func.__name__) if app_name else func.__name__
+        if template == 'text':
+            func = as_text(**response_kwargs)(func)
+        elif template == 'json':
+            func = as_json(**response_kwargs)(func)
+        elif template == 'html':
+            func = as_html(**response_kwargs)(func)
+        else:
+            func = to_template(template, **response_kwargs)(func)
+        for url in [url_or_list] if isinstance(url_or_list, basestring) else url_or_list:
+            urls.add_rule(url, func, urlname)
+        return func
+    return wrapper
+
