@@ -76,21 +76,26 @@ class UrlMap(object):
         cur = self.tree
         res = None, {}
         vals = []
-        for i, dir in enumerate(dirs):
+        i = 0
+        while i < len(dirs):
             for d, node in cur:
-                match, val = node['match'](dir)
+                match, val = node['match'](dirs[i])
                 if match:
                     if val is not None:
-                        vals.append(val)
+                        if val == '<//__slug__//>':
+                            vals.append('/'.join(dirs[i:]))
+                            i = len(dirs) - 1
+                        else:
+                            vals.append(val)
                     break
             else:
                 break
             cur = node['next']
+            i += 1
         else:
-            if i == len(dirs) - 1:
-                vars = dict((node['vars'][i], vals[i])
-                    for i in xrange(len(vals))) if vals else {}
-                res = node['target'], vars
+            vars = dict((node['vars'][i], vals[i])
+                for i in xrange(len(vals))) if vals else {}
+            res = node['target'], vars
         return res
         
 def match_const(var):
@@ -116,10 +121,15 @@ def match_date(var):
         return True, datetime.date(dt.year, dt.month, dt.day)
     return f
 
+def match_slug(var):
+    return lambda dir: (True, '<//__slug__//>')
+
+
 MATCHS = {
     'int': match_int,
     'str': match_str,
     'date': match_date,
+    '*': match_slug,
 }
 
 def get_match(dir):
@@ -135,6 +145,7 @@ REVERSES = {
     'int': lambda var: '%%(%s)i' % var,
     'str': lambda var: '%%(%s)s' % var,
     'date': lambda var: '%%(%s)s' % var,
+    '*': lambda var: '%%(%s)s' % var,
 }
 
 
