@@ -1,11 +1,16 @@
 # -*- coding: utf-8 -*-
-import jinja2
+from os import getcwd
+from os.path import normpath, join, getmtime
+try:
+    import jinja2
+except ImportError, ex:
+    jinja2_ex = ex
 import wsgi
 from config import cfg
-from os.path import normpath, join, getmtime
-from os import getcwd
+from util import obj_from_str
 
-def load_template(fn):
+
+def file_loader(fn):
     ERR_MSG = 'template not found: %s' % fn
     try:
         f = open('templates/%s' % fn)
@@ -25,13 +30,16 @@ def render_to_string(fn, context):
     try:
         return _ENV.get_template(fn).render(context)
     except NameError:
-        _ENV = jinja2.Environment(
-            loader = jinja2.FunctionLoader(load_template),
-            autoescape = True,
-            cache_size = cfg.TEMPLATE_CACHE_SIZE,
-            auto_reload = cfg.TEMPLATE_AUTO_RELOAD,
-            extensions = ['jinja2.ext.with_'],
-        )        
+        try:
+            _ENV = jinja2.Environment(
+                loader = jinja2.FunctionLoader(obj_from_str(cfg.TEMPLATE_LOADER)),
+                autoescape = True,
+                cache_size = cfg.TEMPLATE_CACHE_SIZE,
+                auto_reload = cfg.TEMPLATE_AUTO_RELOAD,
+                extensions = ['jinja2.ext.with_'],
+            )
+        except NameError:
+            raise jinja2_ex
         return _ENV.get_template(fn).render(context)
     
 def render_to_response(rq, fn, context=None, **response_kwargs):
@@ -40,4 +48,5 @@ def render_to_response(rq, fn, context=None, **response_kwargs):
         if k not in context:
             context[k] = v
     return wsgi.Response(render_to_string(fn, context), **response_kwargs)
+
     
