@@ -67,7 +67,10 @@ class Request(object):
             else:
                 body = TemporaryFile(mode='w+b')
             while maxread > 0:
-                part = stream.read(min(maxread, cfg.POST_MAX_MEMFILE))
+                if cfg.POST_MAX_MEMFILE:
+                    part = stream.read(min(maxread, cfg.POST_MAX_MEMFILE))
+                else:
+                    part = stream.read()
                 if not part:  # TODO: Wrong content_length. Error? Do nothing?
                     break
                 body.write(part)
